California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 029 - IMPOSES ADDITIONAL TAX ON CIGARETTES FOR CANCER RESEARCH. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1322759 | YES ON 29 - CALIFORNIANS FOR A CURE, SPONSORED BY THE AMERICAN CANCER SOCIETY CALIFORNIA DIVISION, INC., AMERICAN LUNG ASSOCIATION IN CALIFORNIA, AMERICAN HEART ASSOCIATION & CANCER RESEARCH DOCTORS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1274538 | HOPE 2012 -- YES ON PROP. 29 -- CALIFORNIANS FOR A CANCER CURE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1326622 | YES ON 29, AMERICAN CANCER SOCIETY CANCER ACTION NETWORK INC. AND AMERICAN CANCER SOCIETY INC. BALLOT COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1336203 | NO ON 29 - CALIFORNIANS AGAINST OUT-OF-CONTROL TAXES & SPENDING. MAJOR FUNDING BY PHILIP MORRIS USA & R.J. REYNOLDS TOBACCO, WITH A COALITION OF TAXPAYERS, SMALL BUSINESSES, LAW ENFORCEMENT & LABOR | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1345641 | CALIFORNIA CITIZENS AGAINST WASTEFUL TAXES - NO ON PROP. 29 | OPPOSE